@@ -1,25 +1,26 @@
-/************************************************************************
- FAUST Architecture File
- Copyright (C) 2003-2017 GRAME, Centre National de Creation Musicale
- ---------------------------------------------------------------------
- This Architecture section is free software; you can redistribute it
- and/or modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 3 of
- the License, or (at your option) any later version.
- 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
- 
- You should have received a copy of the GNU General Public License
- along with this program; If not, see <http://www.gnu.org/licenses/>.
- 
- EXCEPTION : As a special exception, you may create a larger work
- that contains this FAUST architecture section and distribute
- that work under terms of your choice, so long as this FAUST
- architecture section is not modified.
- ************************************************************************/
+/************************** BEGIN android-dsp.h **************************
+ / FAUST Architecture File
+Copyright (C) 2003-2022 GRAME, Centre National de Creation Musicale
+---------------------------------------------------------------------
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU Lesser General Public License as published by
+the Free Software Foundation; either version 2.1 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+
+EXCEPTION : As a special exception, you may create a larger work
+that contains this FAUST architecture section and distribute
+that work under terms of your choice, so long as this FAUST
+architecture section is not modified.
+************************************************************************/
 
 #ifndef __android_dsp__
 #define __android_dsp__
@@ -38,7 +39,7 @@
 #define NUM_OUTPUTS 2
 #define CPU_TABLE_SIZE 16
 
-static const char *res_str(SLresult result)
+static const char* res_str(SLresult result)
 {
     switch(result)
     {
@@ -126,7 +127,7 @@ class androidaudio : public audio {
         unsigned int fBufferSize;
     
         int64_t fCPUTable[CPU_TABLE_SIZE];
-        int fCPUTableIndex;
+        int64_t fCPUTableIndex;
     
         float** fInputs;
         float** fOutputs;
@@ -214,13 +215,36 @@ class androidaudio : public audio {
                 __android_log_print(ANDROID_LOG_ERROR, "Faust", "outputCallback Enqueue error = %s", res_str(result));
             }
         }
-          
+    
+        void destroy()
+        {
+            if (fInputBufferQueue) {
+                (*fInputBufferQueue)->Destroy(fInputBufferQueue);
+                fInputBufferQueue = NULL;
+            }
+            
+            if (fOutputBufferQueue) {
+                (*fOutputBufferQueue)->Destroy(fOutputBufferQueue);
+                fOutputBufferQueue = NULL;
+            }
+            
+            if (fOutputMix) {
+                (*fOutputMix)->Destroy(fOutputMix);
+                fOutputMix = NULL;
+            }
+            
+            if (fOpenSLEngine) {
+                (*fOpenSLEngine)->Destroy(fOpenSLEngine);
+                fOpenSLEngine = NULL;
+            }
+        }
+    
     public:
     
         androidaudio(long srate, long bsize)
-        : fDSP(0), fSampleRate(srate),
+        : fDSP(NULL), fSampleRate(srate),
         fBufferSize(bsize), fCPUTableIndex(0), fNumInChans(0), fNumOutChans(0),
-        fOpenSLEngine(0), fOutputMix(0), fInputBufferQueue(0), fOutputBufferQueue(0),
+        fOpenSLEngine(NULL), fOutputMix(NULL), fInputBufferQueue(NULL), fOutputBufferQueue(NULL),
         fOpenSLInputs(bsize * 4, NUM_INPUTS), fOpenSLOutputs(bsize * 4, NUM_OUTPUTS)
         {
             __android_log_print(ANDROID_LOG_ERROR, "Faust", "Constructor");
@@ -243,26 +267,7 @@ class androidaudio : public audio {
         virtual ~androidaudio()
         {
             __android_log_print(ANDROID_LOG_ERROR, "Faust", "Destructor");
-            
-            if (fInputBufferQueue) {
-                (*fInputBufferQueue)->Destroy(fInputBufferQueue);
-                fInputBufferQueue = NULL;
-            }
-            
-            if (fOutputBufferQueue) {
-                (*fOutputBufferQueue)->Destroy(fOutputBufferQueue);
-                fOutputBufferQueue = NULL;
-            }
-            
-            if (fOutputMix) {
-                (*fOutputMix)->Destroy(fOutputMix);
-                fOutputMix = NULL;
-            }
-             
-            if (fOpenSLEngine) {
-                (*fOpenSLEngine)->Destroy(fOpenSLEngine);
-                fOpenSLEngine = NULL;
-            }
+            destroy();
             
             for (int i = 0; i < NUM_INPUTS; i++) {
                 delete [] fInputs[i];
@@ -275,16 +280,6 @@ class androidaudio : public audio {
             delete [] fOutputs;
         }
     
-        // DSP CPU load in percentage of the buffer size duration
-        float getCPULoad()
-        {
-            float sum = 0.f;
-            for (int i = 0; i < CPU_TABLE_SIZE; i++) {
-                sum += fCPUTable[i];
-            }
-            return (sum/float(CPU_TABLE_SIZE))/(10000.f*float(fBufferSize)/float(fSampleRate));
-        }
-    
         virtual bool init(const char* name, dsp* DSP)
         {
             __android_log_print(ANDROID_LOG_ERROR, "Faust", "init");
@@ -339,6 +334,8 @@ class androidaudio : public audio {
                 default:
                     return false;
             }
+            
+            destroy();
           
             // Create the OpenSL ES engine.
             result = slCreateEngine(&fOpenSLEngine, 0, NULL, 0, NULL, NULL);
@@ -570,6 +567,17 @@ class androidaudio : public audio {
             return fNumOutChans;
         }
     
+        // Returns the average proportion of available CPU being spent inside the audio callbacks (between 0 and 1.0).
+        float getCPULoad()
+        {
+            float sum = 0.f;
+            for (int i = 0; i < CPU_TABLE_SIZE; i++) {
+                sum += fCPUTable[i];
+            }
+            return (sum/float(CPU_TABLE_SIZE))/(1000000.f*float(fBufferSize)/float(fSampleRate));
+        }
+    
 };
 
-#endif 
+#endif
+/**************************  END  android-dsp.h **************************/
