@@ -49,6 +49,37 @@ enum SType { kSInt, kSReal };
 
 enum SOperator { kAdd, kSub, kMul, kDiv, kRem, kLsh, kARsh, kLRsh, kGT, kLT, kGE, kLE, kEQ, kNE, kAND, kOR, kXOR };
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+    
+    /**
+     * Print the box.
+     *
+     * @param box - the box to be printed
+     * @param shared - whether the identical sub boxes are printed as identifiers
+     * @param max_size - the maximum number of characters to be printed (possibly needed for big expressions in non shared mode)
+     *
+     * @return the printed box as a string (to be deleted by the caller using freeCMemory)
+     */
+    LIBFAUST_API char* CprintBox(Box box, bool shared, int max_size);
+    
+    /**
+     * Print the signal.
+     *
+     * @param sig - the signal to be printed
+     * @param shared - whether the identical sub signals are printed as identifiers
+     * @param max_size - the maximum number of characters to be printed (possibly needed for big expressions in non shared mode)
+     *
+     * @return the printed signal as a string (to be deleted by the caller using freeCMemory)
+     */
+    LIBFAUST_API char* CprintSignal(Signal sig, bool shared, int max_size);
+    
+#ifdef __cplusplus
+}
+#endif
+
 #endif
 
 #ifndef LIBFAUSTBOX_C_H
@@ -446,6 +477,8 @@ extern "C"
     LIBFAUST_API Box CboxSinAux(Box x);
     LIBFAUST_API Box CboxRint();
     LIBFAUST_API Box CboxRintAux(Box x);
+    LIBFAUST_API Box CboxRound();
+    LIBFAUST_API Box CboxRoundAux(Box x);
     LIBFAUST_API Box CboxLog();
     LIBFAUST_API Box CboxLogAux(Box x);
     LIBFAUST_API Box CboxLog10();
@@ -584,6 +617,33 @@ extern "C"
      */
     LIBFAUST_API Box CboxHBargraphAux(const char* label, Box min, Box max, Box x);
     
+    /**
+     * Create a vertical group box.
+     * @param label - the label definition (see [2])
+     * @param group - the group to be added
+     *
+     * @return the vertical group box.
+     */
+    LIBFAUST_API Box CboxVGroup(const char* label, Box group);
+    
+    /**
+     * Create a horizontal group box.
+     * @param label - the label definition (see [2])
+     * @param group - the group to be added
+     *
+     * @return the horizontal group box.
+     */
+    LIBFAUST_API Box CboxHGroup(const char* label, Box group);
+    
+    /**
+     * Create a tab group box.
+     * @param label - the label definition (see [2])
+     * @param group - the group to be added
+     *
+     * @return the tab group box.
+     */
+    LIBFAUST_API Box CboxTGroup(const char* label, Box group);
+
     /**
      * Create an attach box.
      *
@@ -699,11 +759,40 @@ extern "C"
      */
     LIBFAUST_API Signal* CboxesToSignals(Box box, char* error_msg);
     
+    /**
+     * Create source code in a target language from a box expression.
+     *
+     * @param name_app - the name of the Faust program
+     * @param box - the box expression
+     * @param lang - the target source code's language which can be one of "c",
+     * "cpp", "cmajor", "codebox", "csharp", "dlang", "fir", "interp", "java", "jax",
+     * "jsfx", "julia", "ocpp", "rust" or "wast"
+     * (depending of which of the corresponding backends are compiled in libfaust)
+     * @param argc - the number of parameters in argv array
+     * @param argv - the array of parameters
+     * @param error_msg - the error string to be filled
+     *
+     * @return a string of source code on success (to be deleted by the caller using freeCMemory) or a nullptr and setting error_msg on error.
+     */
+    LIBFAUST_API char* CcreateSourceFromBoxes(const char* name_app, Box box,
+                                            const char* lang,
+                                            int argc, const char* argv[],
+                                            char* error_msg);
+  
+    /**
+     * The free function to be used on memory returned CcreateSourceFromBoxes.
+     *
+     * This is MANDATORY on Windows when otherwise all nasty runtime version related crashes can occur.
+     *
+     * @param ptr - the pointer to be deleted.
+     */
+    LIBFAUST_API void freeCMemory(void* ptr);
+    
     /*
      [1] Constant numerical expression : see https://faustdoc.grame.fr/manual/syntax/#constant-numerical-expressions
      [2] Label definition : https://faustdoc.grame.fr/manual/syntax/#variable-parts-of-a-label
      */
-    
+
 #ifdef __cplusplus
 }
 #endif
