@@ -663,6 +663,33 @@ LIBFAUST_API Box boxHBargraph(const std::string& label, Box min, Box max);
  */
 LIBFAUST_API Box boxHBargraph(const std::string& label, Box min, Box max, Box x);
 
+/**
+ * Create a vertical group box.
+ * @param label - the label definition (see [2])
+ * @param group - the group to be added
+ *
+ * @return the vertical group box.
+ */
+LIBFAUST_API Box boxVGroup(const std::string& label, Box group);
+
+/**
+ * Create a horizontal group box.
+ * @param label - the label definition (see [2])
+ * @param group - the group to be added
+ *
+ * @return the horizontal group box.
+ */
+LIBFAUST_API Box boxHGroup(const std::string& label, Box group);
+
+/**
+ * Create a tab group box.
+ * @param label - the label definition (see [2])
+ * @param group - the group to be added
+ *
+ * @return the tab group box.
+ */
+LIBFAUST_API Box boxTGroup(const std::string& label, Box group);
+
 /**
  * Create an attach box.
  *
